import { styled } from "@mui/material/styles";
import SimpleMDE, { SimpleMDEReactProps } from "react-simplemde-editor";
import "easymde/dist/easymde.min.css";

const StyledMarkdownEditor = styled("div")(() => ({
  "& .editor-toolbar": {
    backgroundColor: "inherit",
    borderColor: "inherit",
  },
  "& .editor-toolbar button": {
    color: "inherit",
  },
  "& .editor-toolbar button:hover": {
    backgroundColor: "inherit",
  },
  "& .editor-toolbar button:active, & .editor-toolbar button.active": {
    backgroundColor: "inherit",
  },
  "& .editor-statusbar": {
    display: "none",
  },
  // Стили для самого редактора
  "& .CodeMirror": {
    backgroundColor: "inherit",
    color: "inherit",
    borderColor: "inherit",
  },
  // Стили для текста в редакторе
  "& .CodeMirror-selected": {
    backgroundColor: "inherit !important",
  },
  "& .CodeMirror-cursor": {
    borderLeftColor: "inherit",
  },
  // Стили для markdown разметки
  "& .cm-header": {
    color: "inherit",
  },
  "& .cm-quote": {
    color: "inherit",
    fontStyle: "italic",
  },
  "& .cm-link": {
    color: "inherit",
  },
  "& .cm-url": {
    color: "inherit",
  },
  "& .cm-formatting": {
    color: "inherit",
  },

  "& .CodeMirror .editor-preview-full": {
    backgroundColor: "inherit",
    color: "inherit",
    borderColor: "inherit",
  },

  "& .EasyMDEContainer": {
    position: "relative",
    zIndex: 1000,
  },
  "& .guide": {
    display: "none",
  },
}));

export const ReactMarkdownEditor = (props: SimpleMDEReactProps) => {
  if (props.options)
    props.options.toolbar = [
      "bold",
      "italic",
      "strikethrough",
      {
        name: "Underline",
        action: (editor: any) => {
          const cm = editor.codemirror;
          let output = "";
          const selectedText = cm.getSelection();
          const text = selectedText ?? "placeholder";

          output = "<u>" + text + "</u>";
          cm.replaceSelection(output);
        },
        className: "fa fa-underline", // Look for a suitable icon
        title: "Underline (Ctrl/Cmd-Alt-U)",
      },
      "heading",
      "quote",
      "unordered-list",
      "ordered-list",
      "link",
      "image",
      "code",
      "table",
      "horizontal-rule",
      "preview",
      "fullscreen",
      "guide",
    ];
  return (
    <StyledMarkdownEditor
      autoFocus={false}
      spellCheck={false}
      sx={{ marginTop: 1.5, marginBottom: 3 }}
    >
      <SimpleMDE {...props} />
    </StyledMarkdownEditor>
  );
};
